## 6.1.0.0 (2023-10-07)

[stubsabot] Bump bleach to 6.1.* (#10852)

Release: https://pypi.org/pypi/bleach/6.1.0
Homepage: https://github.com/mozilla/bleach
Repository: https://github.com/mozilla/bleach
Diff: https://github.com/mozilla/bleach/compare/v6.0.0...v6.1.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 3 files included in typeshed's stubs have been modified or renamed: `bleach/__init__.py`, `bleach/html5lib_shim.py`, `bleach/linkifier.py`.
 - Total lines of Python code added: 41.
 - Total lines of Python code deleted: 14.

## 6.0.0.5 (2023-10-04)

[bleach] Add html5lib_shim.Filter__init__/__iter__ (#10835)

The missing __init__ method caused `Filter` to be incompatible
with the `_Filter` protocol, preventing valid initialization of
`Cleaner` instances.

Closes: #10834

## 6.0.0.4 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 6.0.0.3 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 6.0.0.2 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 6.0.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 6.0.0.0 (2023-01-24)

Upgrade bleach stubs for 6.0 (#9583)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 5.0.3.1 (2022-10-15)

Use `Incomplete` instead of `Any` in `__getattr__` (#8903)

## 5.0.3 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 5.0.2 (2022-04-20)

Use `TypeAlias` for type aliases where possible, part II (#7667)

## 5.0.1 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 5.0.0 (2022-04-12)

Update bleach stubs to version 5 (#7612)

## 4.1.5 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 4.1.3 (2022-01-02)

Never explicitly inherit from `object` in Python 3-only stubs (#6777)

## 4.1.2 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 4.1.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 4.1.0 (2021-08-30)

Update bleach version (no changes) (#5982)

